package cn.feast.coding.mapper.stock;


import cn.feast.coding.mapper.IMapper;
import cn.feast.coding.model.stock.StockAnalyse;

import java.util.List;
import java.util.Map;

/**
 * Created By FeastCoding.
 */
public interface StockAnalyseMapper extends IMapper<StockAnalyse> {
    List<Map<String, Object>> queryAnalyse(String date);

    List<Map<String, Object>> queryAnalyse1();

    List<Map<String, Object>> queryAnalyse2(String date);

    List<Map<String, Object>> sortByTurn();

    List<Map<String, Object>> sortByPrice();

    List<Map<String, Object>> querySentiment();

    List<Map<String, Object>> queryConcept();

    List<Map<String, Object>> queryStockConcept(String stockCode);

    List<Map<String, Object>> queryConceptStocks(String conceptName);

    List<Map<String, Object>> getKLineData(String stockCode);
}